import java.io.*;
import java.util.*;

public class minqueries_ag_ok extends PrintWriter {
    final Random rand = new Random(31);
    final int inf = (int) 1e9;
    final long linf = (long) 1e18;

    final static String IO = "_std";

    class Edge {
        int to, id;

        public Edge(int to, int id) {
            this.to = to;
            this.id = id;
        }
    }

    List<Edge>[] g;
    int[] ts;
    int tsp;
    int[] used;
    int tm = 0;

    void topsort(int v, int md) {
        used[v] = tm;
        for (Edge e : g[v]) {
            if (e.id >= md) {
                break;
            }
            if (used[e.to] != tm) {
                topsort(e.to, md);
            }
        }
        ts[tsp++] = v;
    }

    boolean checkTs(int v, int i, int md) {
        if (i < 0) {
            return true;
        }
        for (Edge e : g[v]) {
            if (e.id >= md) {
                break;
            }
            if (e.to == ts[i]) {
                return checkTs(e.to, i - 1, md);
            }
        }
        return false;
    }

    void solve() throws IOException {
        int n = nextInt();
        int m = nextInt();

        g = createAdjacencyList(n);
        for (int i = 0; i < m; i++) {
            int x = nextInt() - 1;
            int y = nextInt() - 1;
            g[x].add(new Edge(y, i));
        }

        used = new int[n];
        ts = new int[n];

        int l = 0;
        int r = m + 1;
        while (l + 1 < r) {
            int md = (l + r) >> 1;
            tsp = 0;
            ++tm;
            for (int i = 0; i < n; i++) {
                if (used[i] != tm) {
                    topsort(i, md);
                }
            }
            if (checkTs(ts[n - 1], n - 2, md)) {
                r = md;
            } else {
                l = md;
            }
        }

        if (r == m + 1) {
            println(-1);
        } else {
            println(r);
        }
    }

    BufferedReader in;
    StringTokenizer stok;

    minqueries_ag_ok() {
        super(System.out);
        in = new BufferedReader(new InputStreamReader(System.in));
    }

    minqueries_ag_ok(String fileIn, String fileOut) throws IOException {
        super(fileOut);
        in = new BufferedReader(new FileReader(fileIn));
    }

    public static void main(String[] args) throws IOException {
        minqueries_ag_ok main;
        if ("_std".equals(IO)) {
            main = new minqueries_ag_ok();
        } else if ("_iotxt".equals(IO)) {
            main = new minqueries_ag_ok("input.txt", "output.txt");
        } else {
            main = new minqueries_ag_ok(IO + ".in", IO + ".out");
        }
        main.solve();
        main.close();
    }

    String next() throws IOException {
        while (stok == null || !stok.hasMoreTokens()) {
            String s = in.readLine();
            if (s == null) {
                return null;
            }
            stok = new StringTokenizer(s);
        }
        return stok.nextToken();
    }

    int nextInt() throws IOException {
        return Integer.parseInt(next());
    }

    long nextLong() throws IOException {
        return Long.parseLong(next());
    }

    double nextDouble() throws IOException {
        return Double.parseDouble(next());
    }

    int[] nextIntArray(int len) throws IOException {
        int[] a = new int[len];
        for (int i = 0; i < len; i++) {
            a[i] = nextInt();
        }
        return a;
    }

    int[] nextIntArraySorted(int len) throws IOException {
        int[] a = nextIntArray(len);
        shuffle(a);
        Arrays.sort(a);
        return a;
    }

    void shuffle(int[] a) {
        for (int i = 1; i < a.length; i++) {
            int x = rand.nextInt(i + 1);
            int _ = a[i];
            a[i] = a[x];
            a[x] = _;
        }
    }

    void shuffleAndSort(int[] a) {
        shuffle(a);
        Arrays.sort(a);
    }

    boolean nextPermutation(int[] p) {
        for (int a = p.length - 2; a >= 0; --a) {
            if (p[a] < p[a + 1])
                for (int b = p.length - 1; ; --b)
                    if (p[b] > p[a]) {
                        int t = p[a];
                        p[a] = p[b];
                        p[b] = t;
                        for (++a, b = p.length - 1; a < b; ++a, --b) {
                            t = p[a];
                            p[a] = p[b];
                            p[b] = t;
                        }
                        return true;
                    }
        }
        return false;
    }

    <T> List<T>[] createAdjacencyList(int n) {
        List<T>[] res = new List[n];
        for (int i = 0; i < n; i++) {
            res[i] = new ArrayList<>();
        }
        return res;
    }

    void println(Object... a) {
        for (int i = 0; i < a.length; i++) {
            if (i != 0) {
                print(" ");
            }
            print(a[i]);
        }
        println();
    }
}